package eu.digitalconcepts.dcgw.api.telegram;

import java.util.Date;
import java.util.List;

import eu.digitalconcepts.dcgw.api.profile.Direction;


/**
 * API model of encoded EnOcean telegram.
 * 
 * 
 * @author  Digital Concepts GmbH, T. Hennerich
 */
public class Telegram
{
	// ===================================================================================================================================
	// Field Variables
	// ===================================================================================================================================

	/**
	 * Unique ID of the device. 
	 * 
	 * @see #friendlyId
	 * @see #physicalDevice
	 */
	private String deviceId;
	
	/**
	 * Unique alternative clear text ID to address a device or receive telegrams from
	 * in addition to the technical (source) ID.
	 * 
	 * @see #deviceId
	 */
	private String friendlyId;

	/**
	 * Friendly name of the physical device "different individual EEP devices combined in a box".
	 * Unique in the sense of "different physical devices share not the friendly name". 
	 */
	private String physicalDevice;
	
	/**
	 * Timestamp telegram was received / sent.
	 */
	private Date timestamp;
	
	/**
	 * Direction of the telegram.
	 */
	private Direction direction;
	
	/**
	 * List of technical functions.
	 */
	private List<TelegramFunction> functions;
	
	/**
	 * Raw data of the EnOcean telegram.
	 */
	private TelegramInfo telegramInfo;

	
	// ===================================================================================================================================
	// Getter / Setter
	// ===================================================================================================================================

	public String getDeviceId()
    {
    	return deviceId;
    }

	public void setDeviceId(String pDeviceId)
    {
    	deviceId = pDeviceId;
    }

	public String getFriendlyId()
    {
    	return friendlyId;
    }

	public void setFriendlyId(String pFriendlyId)
    {
    	friendlyId = pFriendlyId;
    }

	public String getPhysicalDevice()
    {
    	return physicalDevice;
    }

	public void setPhysicalDevice(String pPhysicalDevice)
    {
    	physicalDevice = pPhysicalDevice;
    }

	public Date getTimestamp()
    {
    	return timestamp;
    }

	public void setTimestamp(Date pTimestamp)
    {
    	timestamp = pTimestamp;
    }

	public Direction getDirection()
    {
    	return direction;
    }

	public void setDirection(Direction pDirection)
    {
    	direction = pDirection;
    }

	public List<TelegramFunction> getFunctions()
	{
		return functions;
	}

	public void setFunctions(List<TelegramFunction> pFunctions)
    {
    	functions = pFunctions;
    }
	
	public TelegramInfo getTelegramInfo()
    {
    	return telegramInfo;
    }

	public void setTelegramInfo(TelegramInfo pTelegramInfo)
    {
    	telegramInfo = pTelegramInfo;
    }	
}
